Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/matomo-org/matomo.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authormattab <matthieu.aubry@gmail.com>2013-06-13 09:31:17 +0400
committermattab <matthieu.aubry@gmail.com>2013-06-16 12:11:03 +0400
commite2b74053c61b0f3d6d44e11472f037a853f5e98a (patch)
treec56c9d5330d565d128e7535c00e990281bc063dd /core/ArchiveProcessor.php
parentdd2140c8c3faf2cfca30fd6fea0350ca953695da (diff)
Renaming ArchiveProcessing in comments as well, adding missing header
Diffstat (limited to 'core/ArchiveProcessor.php')
-rw-r--r--core/ArchiveProcessor.php8
1 files changed, 4 insertions, 4 deletions
diff --git a/core/ArchiveProcessor.php b/core/ArchiveProcessor.php
index 78eceead46..d8245f9a32 100644
--- a/core/ArchiveProcessor.php
+++ b/core/ArchiveProcessor.php
@@ -10,10 +10,10 @@
*/
/**
* The ArchiveProcessing module is a module that reads the Piwik logs from the DB and
* compute all the reports, which are then stored in the database.
*
* The ArchiveProcessing class is used by the Archive object to make sure the given Archive is processed and available in the DB.
*
* A record in the Database for a given report is defined by
* - idarchive = unique ID that is associated to all the data of this archive (idsite+period+date)
@@ -178,7 +178,7 @@ abstract class Piwik_ArchiveProcessor
return $idArchive;
}
- if (!Piwik_DataAccess_Archiver::getArchiveProcessingLock($this->getSite()->getId(), $this->getPeriod(), $this->getSegment())) {
+ if (!Piwik_DataAccess_Archiver::getArchiveProcessorLock($this->getSite()->getId(), $this->getPeriod(), $this->getSegment())) {
Piwik::log('Unable to get lock for idSite = ' . $this->getSite()->getId()
. ', period = ' . $this->getPeriod()->getLabel()
. ', UTC datetime [' . $this->getDateStart()->getDateStartUTC() . ' -> ' . $this->getDateEnd()->getDateEndUTC() . ' ]...');
@@ -224,7 +224,7 @@ abstract class Piwik_ArchiveProcessor
}
$this->insertNumericRecord($done, $flag);
- Piwik_DataAccess_Archiver::releaseArchiveProcessingLock($this->getSite()->getId(), $this->getPeriod(), $this->getSegment());
+ Piwik_DataAccess_Archiver::releaseArchiveProcessorLock($this->getSite()->getId(), $this->getPeriod(), $this->getSegment());
return $idArchive;
@@ -10,10 +10,10 @@
*/
/**
- * The ArchiveProcessing module is a module that reads the Piwik logs from the DB and
+ * The ArchiveProcessor module is a module that reads the Piwik logs from the DB and
* compute all the reports, which are then stored in the database.
*
@@ -10,10 +10,10 @@
* compute all the reports, which are then stored in the database.
*
- * The ArchiveProcessing class is used by the Archive object to make sure the given Archive is processed and available in the DB.
+ * The ArchiveProcessor class is used by the Archive object to make sure the given Archive is processed and available in the DB.
*
* A record in the Database for a given report is defined by